pub enum AzElError {
InvalidAzimuth(Angle),
InvalidElevation(Angle),
}Expand description
Error returned when constructing an AzEl with invalid angles.
Variants
InvalidAzimuth(Angle)
The azimuth angle is outside the valid range [0°, 360°].
InvalidElevation(Angle)
The elevation angle is outside the valid range [0°, 360°].