Module elements

Module elements 

Data types for representing orbital elements.

Structs

ArgumentOfPeriapsis
Argument of periapsis.
ArgumentOfPeriapsisError
Error returned when an ArgumentOfPeriapsis is outside the valid range [0°, 360°].
Eccentricity
Orbital eccentricity.
GravitationalParameter
The standard gravitational parameter of a celestial body µ = GM.
Inclination
Orbital inclination.
InclinationError
Error returned when an Inclination is outside the valid range [0°, 180°].
Keplerian
A set of Keplerian orbital elements.
KeplerianBuilder
Builder for constructing validated Keplerian elements.
LongitudeOfAscendingNode
Longitude of ascending node.
LongitudeOfAscendingNodeError
Error returned when a LongitudeOfAscendingNode is outside the valid range [0°, 360°].
NegativeEccentricityError
Error returned when attempting to create an Eccentricity with a negative value.

Enums

KeplerianError
Error returned when constructing a Keplerian via the builder.
OrbitType
The Keplerian orbit types or conic sections.

Type Aliases

SemiMajorAxis
Type alias for the semi-major axis of an orbit, stored as a Distance.