RootFinderError

Enum RootFinderError 

pub enum RootFinderError {
    NotConverged {
        iterations: u32,
        x: f64,
        residual: f64,
    },
    NotInBracket,
    NonFinite {
        x: f64,
        value: f64,
    },
    NonFiniteDerivative {
        x: f64,
        value: f64,
    },
    DivergedStep {
        x: f64,
    },
    Callback(LoxError),
}
Error returned by root-finding algorithms.

Variants



NotConverged

The algorithm did not converge within the maximum number of iterations.

Fields

iterations: u32

Number of iterations performed before giving up.

x: f64

The best root estimate reached.

residual: f64

The residual f(x) at the best estimate.



NotInBracket

The root is not within the given bracket.



NonFinite

The objective function returned a non-finite value.

Fields

x: f64

The point at which the function was evaluated.

value: f64

The non-finite value returned.



NonFiniteDerivative

The derivative returned a non-finite value.

Fields

x: f64

The point at which the derivative was evaluated.

value: f64

The non-finite value returned.



DivergedStep

The iteration update diverged, e.g. due to a zero derivative at a stationary point or a vanishing update denominator.

Fields

x: f64

The iterate at which the update diverged.



Callback(LoxError)

The objective function returned an error.