Angle

Struct Angle 

pub struct Angle(/* private fields */);
Angle in radians.

Implementations

Source

impl Angle

pub const ZERO: Self

An angle equal to zero.

pub const PI: Self

An angle equal to π.

pub const TAU: Self

An angle equal to τ = 2π.

pub const FRAC_PI_2: Self

An angle equal to π/2.

pub const FRAC_PI_4: Self

An angle equal to π/4.

pub const fn new(rad: f64) -> Self

Creates a new angle from an f64 value in radians.

pub const fn radians(rad: f64) -> Self

Creates a new angle from an f64 value in radians.

pub const fn radians_normalized(rad: f64) -> Self

Creates a new angle from an f64 value in radians and normalize the angle to the interval [0.0, 2π).

pub const fn radians_normalized_signed(rad: f64) -> Self

Creates a new angle from an f64 value in radians and normalize the angle to the interval (-2π, 2π).

pub const fn degrees(deg: f64) -> Self

Creates a new angle from an f64 value in degrees.

pub const fn from_hms(hours: i64, minutes: u8, seconds: f64) -> Self

Creates a new angle from hours, minutes, and seconds (HMS notation).

pub const fn degrees_normalized(deg: f64) -> Self

Creates a new angle from an f64 value in degrees and normalize the angle to the interval [0.0, 2π).

pub const fn degrees_normalized_signed(deg: f64) -> Self

Creates a new angle from an f64 value in degrees and normalize the angle to the interval (-2π, 2π).

pub const fn arcseconds(asec: f64) -> Self

Creates a new angle from an f64 value in arcseconds.

pub const fn arcseconds_normalized(asec: f64) -> Self

Creates a new angle from an f64 value in arcseconds and normalize the angle to the interval [0.0, 2π).

pub const fn arcseconds_normalized_signed(asec: f64) -> Self

Creates a new angle from an f64 value in arcseconds and normalize the angle to the interval (-2π, 2π).

pub fn is_zero(&self) -> bool

Returns true if the angle is exactly zero.

pub const fn abs(&self) -> Self

Returns the absolute value of the angle.

pub fn from_asin(value: f64) -> Self

Creates an angle from the arcsine of a value.

pub fn from_asinh(value: f64) -> Self

Creates an angle from the inverse hyperbolic sine of a value.

pub fn from_acos(value: f64) -> Self

Creates an angle from the arccosine of a value.

pub fn from_acosh(value: f64) -> Self

Creates an angle from the inverse hyperbolic cosine of a value.

pub fn from_atan(value: f64) -> Self

Creates an angle from the arctangent of a value.

pub fn from_atanh(value: f64) -> Self

Creates an angle from the inverse hyperbolic tangent of a value.

pub fn from_atan2(y: f64, x: f64) -> Self

Creates an angle from the two-argument arctangent of y and x.

pub fn cos(&self) -> f64

Returns the cosine of the angle.

pub fn cosh(&self) -> f64

Returns the hyperbolic cosine of the angle.

pub fn sin(&self) -> f64

Returns the sine of the angle.

pub fn sinh(&self) -> f64

Returns the hyperbolic sine of the angle.

pub fn sin_cos(&self) -> (f64, f64)

Returns sine and cosine of the angle.

pub fn tan(&self) -> f64

Returns the tangent of the angle.

pub fn tanh(&self) -> f64

Returns the hyperbolic tangent of the angle.

pub const fn mod_two_pi(&self) -> Self

Returns a new angle that is normalized to the interval [0.0, 2π).

pub const fn mod_two_pi_signed(&self) -> Self

Returns a new angle that is normalized to the interval (-2π, 2π).

pub const fn normalize_two_pi(&self, center: Self) -> Self

Returns a new angle that is normalized to a (-π, π) interval centered around center.

pub const fn as_f64(&self) -> f64

Returns the value of the angle in radians.

pub const fn to_radians(&self) -> f64

Returns the value of the angle in radians.

pub const fn to_degrees(&self) -> f64

Returns the value of the angle in degrees.

pub const fn to_arcseconds(&self) -> f64

Returns the value of the angle in arcseconds.

pub fn rotation_x(&self) -> DMat3

Returns the 3×3 rotation matrix for a rotation about the X axis.

pub fn rotation_y(&self) -> DMat3

Returns the 3×3 rotation matrix for a rotation about the Y axis.

pub fn rotation_z(&self) -> DMat3

Returns the 3×3 rotation matrix for a rotation about the Z axis.