pub struct KeplerianBuilder { /* private fields */ }Expand description
Builder for constructing validated Keplerian elements.
Implementations
Sourceimpl KeplerianBuilder
impl KeplerianBuilder
Sourcepub fn with_semi_major_axis(
self,
semi_major_axis: SemiMajorAxis,
eccentricity: f64,
) -> Self
pub fn with_semi_major_axis( self, semi_major_axis: SemiMajorAxis, eccentricity: f64, ) -> Self
Sets the semi-major axis and eccentricity.
Sourcepub fn with_radii(
self,
periapsis_radius: Distance,
apoapsis_radius: Distance,
) -> Self
pub fn with_radii( self, periapsis_radius: Distance, apoapsis_radius: Distance, ) -> Self
Sets the orbit shape from periapsis and apoapsis radii.
Sourcepub fn with_altitudes(
self,
periapsis_altitude: Distance,
apoapsis_altitude: Distance,
mean_radius: Distance,
) -> Self
pub fn with_altitudes( self, periapsis_altitude: Distance, apoapsis_altitude: Distance, mean_radius: Distance, ) -> Self
Sets the orbit shape from periapsis and apoapsis altitudes above a mean radius.
Sourcepub fn with_inclination(self, inclination: Angle) -> Self
pub fn with_inclination(self, inclination: Angle) -> Self
Sets the inclination.
Sourcepub fn with_longitude_of_ascending_node(
self,
longitude_of_ascending_node: Angle,
) -> Self
pub fn with_longitude_of_ascending_node( self, longitude_of_ascending_node: Angle, ) -> Self
Sets the longitude of ascending node.
Sourcepub fn with_argument_of_periapsis(self, argument_of_periapsis: Angle) -> Self
pub fn with_argument_of_periapsis(self, argument_of_periapsis: Angle) -> Self
Sets the argument of periapsis.
Sourcepub fn with_true_anomaly(self, true_anomaly: Angle) -> Self
pub fn with_true_anomaly(self, true_anomaly: Angle) -> Self
Sets the true anomaly.
Sourcepub fn with_mean_anomaly(self, mean_anomaly: Angle) -> Self
pub fn with_mean_anomaly(self, mean_anomaly: Angle) -> Self
Sets the mean anomaly (converted to true anomaly during build).